<?php

/*
 * Plugin Name: Post Hit Counter (Workshop)
 * Version: 1.0
 * Plugin URI: https://wordpress.org/plugins/post-hit-counter/
 * Description: A counter to track how many times your posts are viewed.
 * Author: Hugh Lashbrooke
 * Author URI: http://www.hughlashbrooke.com/
 * Requires at least: 4.0
 * Tested up to: 4.0
 */











/*
Count post views
 */
add_action( 'wp', 'post_hit_counter_count_post_view' );
function post_hit_counter_count_post_view () {

	// Check if this is a single post page
	if( is_single() ) {

		// Get post object
		global $post;

		// Only run if this is the 'post' post type
		if( 'post' == $post->post_type ) {

			// Get saved view count
			$views = intval( get_post_meta( $post->ID, '_post_views', true ) );

			// Increment view count
			$views_updated = $views + 1;

			// Save new view count
			update_post_meta( $post->ID, '_post_views', $views_updated, $views );
		}

	}

}











/*
Add column to post list table
 */
add_filter( 'manage_post_posts_columns', 'post_hit_counter_add_post_views_column' );
function post_hit_counter_add_post_views_column ( $columns ) {

	// Add new 'Views' columns
	$columns['views'] = 'Views';

	// Return full column array
	return $columns;

}











/*
Display content for post views column
 */
add_action( 'manage_post_posts_custom_column', 'post_hit_counter_display_post_views_column', 10, 2 );
function post_hit_counter_display_post_views_column ( $column = '', $post_id = 0 ) {

	// Only show column if this is the 'post' list table
	if( 'post' != get_post_type( $post_id ) ) {
		return;
	}

	// Only show this content if this is the 'views' column
	if( 'views' == $column ) {

		// Get saved view count
		$views = intval( get_post_meta( $post_id, '_post_views', true ) );

		// Display view count
		echo $views;

	}

}











/*
Display post views on post edit screen
 */
add_action( 'post_submitbox_misc_actions', 'post_hit_counter_display_post_views_meta' );
function post_hit_counter_display_post_views_meta () {

	// Get relevant global variables
	global $post, $pagenow, $typenow;

	// Only show if this is the post edit screen
	if( 'post.php' == $pagenow && 'post' == $typenow ) {

		// Get saved view count
		$views = intval( get_post_meta( $post->ID, '_post_views', true ) );

		// Display markup with view count
		?>
		<div class="misc-pub-section misc-pub-post-views" id="post-views">
			<?php echo 'Views:'; ?>
			<strong><?php echo esc_html( $views ); ?></strong>
		</div>
		<?php

	}

}











/*
Load styles for post views on post edit screen
 */
add_action( 'admin_enqueue_scripts', 'post_hit_counter_admin_enqueue_styles' );
function post_hit_counter_admin_enqueue_styles () {

	wp_register_style( 'post_hit_counter-admin', plugins_url( 'admin.css', __FILE__ ) );
	wp_enqueue_style( 'post_hit_counter-admin' );

}